# (C) Copyright 2023- ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
#


try:
    # NOTE: the `_version.py` file must not be present in the git repository
    #   as it is generated by setuptools at install time
    from ._version import __version__
except ImportError:  # pragma: no cover
    # Local copy or not installed with setuptools
    __version__ = "999"

import earthkit.data as data
import earthkit.geo as geo
import earthkit.hydro as hydro
import earthkit.meteo as meteo
import earthkit.plots as plots
import earthkit.regrid as regrid
import earthkit.time as time
import earthkit.transforms as transforms

__all__ = [
    "data",
    "geo",
    "meteo",
    "plots",
    "regrid",
    "time",
    "transforms",
    "hydro",
    "__version__",
]
